@@ -21,15 +21,12 @@
 #include "contextbuilder.h"
 
 
-#include <ktexteditor/smartrange.h>
-#include <ktexteditor/smartinterface.h>
 #include <ktexteditor/document.h>
 
 #include <language/duchain/duchain.h>
 #include <language/duchain/topducontext.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/use.h>
-#include <language/duchain/smartconverter.h>
 #include <util/pushvalue.h>
 
 #include "parsesession.h"
@@ -57,7 +54,7 @@ bool containsContext( const QList<LineContextPair>& lineContexts, TopDUContext*
 
 bool importsContext( const QList<LineContextPair>& lineContexts, TopDUContext* context ) {
   foreach( const LineContextPair& ctx, lineContexts )
-    if( ctx.context && ctx.context->imports(context, KDevelop::SimpleCursor()) )
+    if( ctx.context && ctx.context->imports(context, KDevelop::CursorInRevision()) )
       return true;
   return false;
 }
@@ -96,22 +93,8 @@ void getFirstLast(AST** first, AST** last, const ListNode<_Tp> *nodes)
   while (it != end);
 }
 
-
-ContextBuilder::ContextBuilder ()
-  : m_nameCompiler(0)
-  , m_inFunctionDefinition(false)
-  , m_templateDeclarationDepth(0)
-  , m_typeSpecifierWithoutInitDeclarators((uint)-1)
-  , m_onlyComputeVisible(false)
-  , m_onlyComputeSimplified(false)
-  , m_computeEmpty(false)
-  , m_currentInitializer(0)
-  , m_mapAst(false)
-{
-}
-
 ContextBuilder::ContextBuilder (ParseSession* session)
-  : m_nameCompiler(0)
+: m_nameCompiler(session)
   , m_inFunctionDefinition(false)
   , m_templateDeclarationDepth(0)
   , m_typeSpecifierWithoutInitDeclarators((uint)-1)
@@ -120,22 +103,8 @@ ContextBuilder::ContextBuilder (ParseSession* session)
   , m_computeEmpty(false)
   , m_currentInitializer(0)
   , m_mapAst(false)
+  , m_editor(session)
 {
-  setEditor(new CppEditorIntegrator(session), true);
-}
-
-ContextBuilder::ContextBuilder (CppEditorIntegrator* editor)
-  : m_nameCompiler(0)
-  , m_inFunctionDefinition(false)
-  , m_templateDeclarationDepth(0)
-  , m_typeSpecifierWithoutInitDeclarators((uint)-1)
-  , m_onlyComputeVisible(false)
-  , m_onlyComputeSimplified(false)
-  , m_computeEmpty(false)
-  , m_currentInitializer(0)
-  , m_mapAst(false)
-{
-  setEditor(editor, false);
 }
 
 void ContextBuilder::setOnlyComputeVisible(bool onlyVisible) {
@@ -158,7 +127,7 @@ void ContextBuilder::createUserProblem(AST* node, QString text) {
     KDevelop::ProblemPointer problem(new KDevelop::Problem);
     problem->setDescription(text);
     problem->setSource(KDevelop::ProblemData::DUChainBuilder);
-    problem->setFinalLocation(DocumentRange(HashedString(currentContext()->url().str()), editor()->findRange(node).textRange()));
+    problem->setFinalLocation(DocumentRange(IndexedString(currentContext()->url().str()), editor()->findRange(node).castToSimpleRange()));
     currentContext()->topContext()->addProblem(problem);
 }
 
@@ -188,13 +157,6 @@ void ContextBuilder::addBaseType( KDevelop::BaseClassInstance base, BaseSpecifie
   }
 }
 
-void ContextBuilder::setEditor(CppEditorIntegrator* editor, bool ownsEditorIntegrator)
-{
-  ContextBuilderBase::setEditor(editor, ownsEditorIntegrator);
-  m_nameCompiler = new NameCompiler(editor->parseSession());
-}
-
-
 void addImportedParentContextSafely(DUContext* context, DUContext* import) {
   if(import->imports(context)) {
     kDebug() << "prevented endless recursive import";
@@ -234,22 +196,21 @@ DUContext* ContextBuilder::contextFromNode( AST* node )
   return node->ducontext;
 }
 
-KTextEditor::Range ContextBuilder::editorFindRange( AST* fromRange, AST* toRange )
+RangeInRevision ContextBuilder::editorFindRange( AST* fromRange, AST* toRange )
 {
-  return editor()->findRange(fromRange, toRange).textRange();
+  return editor()->findRange(fromRange, toRange);
 }
 
-KTextEditor::Range ContextBuilder::editorFindRangeForContext( AST* fromRange, AST* toRange )
+RangeInRevision ContextBuilder::editorFindRangeForContext( AST* fromRange, AST* toRange )
 {
-  return editor()->findRangeForContext(fromRange->start_token, toRange->end_token).textRange();
+  return editor()->findRangeForContext(fromRange->start_token, toRange->end_token);
 }
 
 ContextBuilder::~ContextBuilder ()
 {
-  delete m_nameCompiler;
 }
 
-QPair<DUContext*, QualifiedIdentifier> ContextBuilder::findPrefixContext(const QualifiedIdentifier& id, KDevelop::SimpleCursor pos) {
+QPair<DUContext*, QualifiedIdentifier> ContextBuilder::findPrefixContext(const QualifiedIdentifier& id, KDevelop::CursorInRevision pos) {
   if(id.count() < 2)
     return qMakePair((DUContext*)0, QualifiedIdentifier());
   
@@ -282,7 +243,7 @@ QPair<DUContext*, QualifiedIdentifier> ContextBuilder::findPrefixContext(const Q
   return qMakePair(import, prefixId);
 }
 
-void ContextBuilder::openPrefixContext(AST* ast, const QualifiedIdentifier& id, const SimpleCursor& pos) {
+void ContextBuilder::openPrefixContext(AST* ast, const QualifiedIdentifier& id, const CursorInRevision& pos) {
   if(id.count() < 2)
     return;
 
@@ -338,9 +299,6 @@ KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::Enviro
   Cpp::EnvironmentFile* filePtr = const_cast<Cpp::EnvironmentFile*>(file.data() );
   
   filePtr->setIsProxyContext(true);
-  
-  //Never give smart-ranges to proxy-contexts
-  editor()->setCurrentUrl(file->url(), false);
 
   TopDUContext* topLevelContext = 0;
   {
@@ -359,7 +317,7 @@ KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::Enviro
     } else {
       kDebug(9007) << "ContextBuilder::buildProxyContextFromContent: compiling";
 
-      topLevelContext = new CppDUContext<TopDUContext>(editor()->currentUrl(), SimpleRange(), filePtr);
+      topLevelContext = new CppDUContext<TopDUContext>(file->url(), RangeInRevision(), filePtr);
       topLevelContext->setType(DUContext::Global);
 
       Q_ASSERT(dynamic_cast<CppDUContext<TopDUContext>* >(topLevelContext));
@@ -370,15 +328,12 @@ KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::Enviro
       topLevelContext->updateImportsCache(); //Mark that we will use a cached import-structure
     }
 
-    if(content) {
-      cppContext->clearImportedParentContexts();
-      cppContext->addImportedParentContext(content.data());
-      cppContext->updateImportsCache(); //Mark that we will use a cached import-structure
-    } else {
-      ///This happens if a content-context is deleted from the du-chain during the time that the du-chain is not locked by this thread
-      kDebug(9007) << "ContextBuilder::buildProxyContextFromContent: Content-context lost for " << file->url().str();
-      Q_ASSERT(0);
-    }
+    Q_ASSERT(content);
+    
+    cppContext->clearImportedParentContexts();
+    cppContext->addImportedParentContext(content.data());
+    cppContext->updateImportsCache(); //Mark that we will use a cached import-structure
+
     Q_ASSERT(topLevelContext->importedParentContexts().count());
   }
 
@@ -397,46 +352,27 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
       updateContext->parsingEnvironmentFile()->setIsProxyContext(false);
     }
   }
-
-  if(editor()->currentUrl() != file->url())
-    editor()->setCurrentUrl(file->url(), true);
-
+  
   ReferencedTopDUContext topLevelContext;
   {
     DUChainWriteLocker lock(DUChain::lock());
     topLevelContext = updateContext;
 
-    if( topLevelContext && topLevelContext->smartRange() && !(topLevelContext->parsingEnvironmentFile() && topLevelContext->parsingEnvironmentFile()->isProxyContext()))
-      if (topLevelContext->smartRange()->parentRange()) { //Top-range must have no parent, else something is wrong with the structure
-        kWarning() << *topLevelContext->smartRange() << "erroneously has a parent range" << *topLevelContext->smartRange()->parentRange();
-        Q_ASSERT(false);
-      }
-
+    RangeInRevision topRange = RangeInRevision(CursorInRevision(0,0), CursorInRevision(INT_MAX, INT_MAX));
+    
     if (topLevelContext) {
       kDebug(9007) << "ContextBuilder::buildContexts: recompiling";
       setRecompiling(true);
-
-      if (compilingContexts()) {
-        // To here...
-        LockedSmartInterface iface = editor()->smart();
-        if (iface && topLevelContext->range().textRange() != iface.currentDocument()->documentRange()) {
-          topLevelContext->setRange(SimpleRange(iface.currentDocument()->documentRange()));
-          //This happens the whole file is deleted, and then a space inserted.
-          kDebug(9007) << "WARNING: Top-level context has wrong size: " << topLevelContext->range().textRange() << " should be: " << iface.currentDocument()->documentRange();
-        }
-      }
-
       DUChain::self()->updateContextEnvironment( topLevelContext, const_cast<Cpp::EnvironmentFile*>(file.data() ) );
+      topLevelContext->setRange(topRange);
     } else {
       kDebug(9007) << "ContextBuilder::buildContexts: compiling";
       setRecompiling(false);
 
       Q_ASSERT(compilingContexts());
 
-      LockedSmartInterface iface = editor()->smart();
-      topLevelContext = new CppDUContext<TopDUContext>(editor()->currentUrl(), iface.currentDocument() ? SimpleRange(iface.currentDocument()->documentRange()) : SimpleRange(SimpleCursor(0,0), SimpleCursor(INT_MAX, INT_MAX)), const_cast<Cpp::EnvironmentFile*>(file.data()));
+      topLevelContext = new CppDUContext<TopDUContext>(file->url(), topRange, const_cast<Cpp::EnvironmentFile*>(file.data()));
 
-      topLevelContext->setSmartRange(editor()->topRange(iface, CppEditorIntegrator::DefinitionUseChain), DocumentRangeObject::Own);
       topLevelContext->setType(DUContext::Global);
       topLevelContext->setFlags((TopDUContext::Flags)(TopDUContext::UpdatingContext | topLevelContext->flags()));
       DUChain::self()->addDocumentChain(topLevelContext);
@@ -453,13 +389,13 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
             topLevelContext->removeImportedParentContext(parent.context(0));
       }
 
-      QList< QPair<TopDUContext*, SimpleCursor> > realIncluded;
-      QList< QPair<TopDUContext*, SimpleCursor> > realTemporaryIncluded;
+      QList< QPair<TopDUContext*, CursorInRevision> > realIncluded;
+      QList< QPair<TopDUContext*, CursorInRevision> > realTemporaryIncluded;
       foreach (const LineContextPair &included, *includes)
         if(!included.temporary)
-          realIncluded << qMakePair(included.context.data(), SimpleCursor(included.sourceLine, 0));
+          realIncluded << qMakePair(included.context.data(), CursorInRevision(included.sourceLine, 0));
         else
-          realTemporaryIncluded << qMakePair(included.context.data(), SimpleCursor(included.sourceLine, 0));
+          realTemporaryIncluded << qMakePair(included.context.data(), CursorInRevision(included.sourceLine, 0));
 
       topLevelContext->addImportedParentContexts(realIncluded);
       topLevelContext->addImportedParentContexts(realTemporaryIncluded, true);
@@ -471,7 +407,7 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
   {
     DUChainReadLocker lock(DUChain::lock());
     //If we're debugging the current file, dump its preprocessed contents and the AST
-    ifDebugFile( HashedString(file->identity().url().str()), { kDebug() << stringFromContents(editor()->parseSession()->contentsVector()); Cpp::DumpChain dump; dump.dump(node, editor()->parseSession()); } );
+    ifDebugFile( IndexedString(file->identity().url().str()), { kDebug() << stringFromContents(editor()->parseSession()->contentsVector()); Cpp::DumpChain dump; dump.dump(node, editor()->parseSession()); } );
   }
 
   if(m_computeEmpty)
@@ -480,28 +416,20 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
     DUChainWriteLocker lock(DUChain::lock());
     topLevelContext->cleanIfNotEncountered(QSet<DUChainBase*>());
   }else{
+    Q_ASSERT(node);
     node->ducontext = topLevelContext;
     supportBuild(node);
   }
 
-  {
-    LockedSmartInterface iface = editor()->smart();
-    if (iface && topLevelContext->range().textRange() != iface.currentDocument()->documentRange()) {
-      kDebug(9007) << "WARNING: Top-level context has wrong size: " << topLevelContext->range().textRange() << " should be: " << iface.currentDocument()->documentRange();
-      topLevelContext->setRange( SimpleRange(iface.currentDocument()->documentRange()) );
-    }
-  }
-
   {
     DUChainReadLocker lock(DUChain::lock());
 
     kDebug(9007) << "built top-level context with" << topLevelContext->localDeclarations().size() << "declarations and" << topLevelContext->importedParentContexts().size() << "included files";
     //If we're debugging the current file, dump the du-chain and the smart ranges
-    ifDebugFile( HashedString(file->identity().url().str()), { KDevelop::DumpChain dump; dump.dump(topLevelContext); if(topLevelContext->smartRange()) dump.dumpRanges(topLevelContext->smartRange()); } );
+    ifDebugFile( IndexedString(file->identity().url().str()), { KDevelop::dumpDUContext(topLevelContext); } );
 
 /*     if( m_recompiling ) {
-      DumpChain dump;
-      dump.dump(topLevelContext);
+      dumpDUContext(topLevelContext);
       kDebug(9007) << dump.dotGraph(topLevelContext);
      }*/
   }
@@ -522,41 +450,6 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
   return topLevelContext;
 }
 
-// KDevelop::DUContext* ContextBuilder::buildSubContexts(const HashedString& url, AST *node, KDevelop::DUContext* parent) {
-//   setCompilingContexts(true);
-//   setRecompiling(false);
-//
-//   editor()->setCurrentUrl(url);
-//
-//   node->ducontext = parent;
-//
-//   {
-//     //copied out of supportBuild
-//
-//     openContext(node->ducontext);
-//
-//     editor()->setCurrentRange(editor()->topRange(EditorIntegrator::DefinitionUseChain));
-//
-//     visit (node);
-//
-//     closeContext();
-//   }
-//
-//   setCompilingContexts(false);
-//
-//   if( node->ducontext == parent ) {
-//     //The node's du-context should have been replaced!
-//     //Maybe dump the node
-//     kDebug(9007) << "Error in ContextBuilder::buildSubContexts(...): du-context was not replaced with new one";
-//     DUChainWriteLocker lock(DUChain::lock());
-//     delete node->ducontext;
-//
-//     node->ducontext = 0;
-//   }
-//
-//   return node->ducontext;
-// }
-
 void ContextBuilder::visitNamespace (NamespaceAST *node)
 {
   QualifiedIdentifier identifier;
@@ -719,7 +612,7 @@ DUContext* ContextBuilder::openContextEmpty(AST* rangeNode, DUContext::ContextTy
 #ifdef DEBUG_UPDATE_MATCHING
     kDebug() << "opening context with text" << editor()->tokensToStrings( rangeNode->start_token, rangeNode->end_token );
 #endif
-    KDevelop::SimpleRange range = editor()->findRangeForContext(rangeNode->start_token, rangeNode->end_token);
+    KDevelop::RangeInRevision range = editor()->findRangeForContext(rangeNode->start_token, rangeNode->end_token);
     range.end = range.start;
     DUContext* ret = openContextInternal(range, type, QualifiedIdentifier());
     rangeNode->ducontext = ret;
@@ -727,15 +620,11 @@ DUContext* ContextBuilder::openContextEmpty(AST* rangeNode, DUContext::ContextTy
 
   } else {
     openContext(rangeNode->ducontext);
-    {
-      LockedSmartInterface iface = editor()->smart();
-      editor()->setCurrentRange(iface, currentContext()->smartRange());
-    }
     return currentContext();
   }
 }
 
-DUContext* ContextBuilder::openContextInternal(const KDevelop::SimpleRange& range, DUContext::ContextType type, const QualifiedIdentifier& identifier)
+DUContext* ContextBuilder::openContextInternal(const KDevelop::RangeInRevision& range, DUContext::ContextType type, const QualifiedIdentifier& identifier)
 {
   DUContext* ret = ContextBuilderBase::openContextInternal(range, type, identifier);
 
@@ -754,7 +643,7 @@ DUContext* ContextBuilder::openContextInternal(const KDevelop::SimpleRange& rang
   return ret;
 }
 
-DUContext* ContextBuilder::newContext(const SimpleRange& range)
+DUContext* ContextBuilder::newContext(const RangeInRevision& range)
 {
   return new CppDUContext<DUContext>(range, currentContext());
 }
@@ -762,7 +651,7 @@ DUContext* ContextBuilder::newContext(const SimpleRange& range)
 #ifdef DEBUG_CONTEXT_RANGES
 void ContextBuilder::checkRanges()
 {
-  for(QHash<KDevelop::DUContext*, KDevelop::SimpleRange>::iterator it = m_contextRanges.begin(); it != m_contextRanges.end(); ) {
+  for(QHash<KDevelop::DUContext*, KDevelop::RangeInRevision>::iterator it = m_contextRanges.begin(); it != m_contextRanges.end(); ) {
     if(it.key()->range() != *it) {
       kDebug(9007) << "Range of" << it.key()->scopeIdentifier(true).toString() << "changed from" << (*it).textRange() << "to" << it.key()->range().textRange() << "at\n" << kBacktrace();
       it = m_contextRanges.erase(it); //Remove it so we see each change only once
@@ -836,7 +725,7 @@ class VerifyExpressionVisitor : public Cpp::ExpressionVisitor {
 class IdentifierVerifier : public DefaultVisitor
 {
 public:
-  IdentifierVerifier(ContextBuilder* _builder, const SimpleCursor& _cursor)
+  IdentifierVerifier(ContextBuilder* _builder, const CursorInRevision& _cursor)
     : builder(_builder)
     , result(true)
     , cursor(_cursor)
@@ -845,7 +734,7 @@ public:
 
   ContextBuilder* builder;
   bool result; //Will be true when this should be an expression, else false.
-  SimpleCursor cursor;
+  CursorInRevision cursor;
 
   void visitPostfixExpression(PostfixExpressionAST* node)
   {
@@ -909,7 +798,7 @@ void ContextBuilder::visitExpressionOrDeclarationStatement(ExpressionOrDeclarati
 
         node->expression->ducontext = currentContext();
         iv.parse(node->expression);*/
-        IdentifierVerifier iv(this, SimpleCursor(editor()->findPosition(node->start_token)));
+        IdentifierVerifier iv(this, CursorInRevision(editor()->findPosition(node->start_token)));
         iv.visit(node->expression);
         //kDebug(9007) << editor()->findPosition(node->start_token) << "IdentifierVerifier returned" << iv.result;
         node->expressionChosen = iv.result;
@@ -991,7 +880,7 @@ void ContextBuilder::visitInitDeclarator(InitDeclaratorAST *node)
   QualifiedIdentifier id;
   if(node->declarator && node->declarator->id && node->declarator->id->qualified_names && (!node->declarator->parameter_declaration_clause || node->declarator->parameter_is_initializer)) {
     //Build a prefix-context for external variable-definitions
-    SimpleCursor pos = editor()->findPosition(node->start_token, KDevelop::EditorIntegrator::FrontEdge);
+    CursorInRevision pos = editor()->findPosition(node->start_token, CppEditorIntegrator::FrontEdge);
     identifierForNode(node->declarator->id, id);
     
     openPrefixContext(node, id, pos);
@@ -1218,11 +1107,7 @@ void ContextBuilder::identifierForNode(NameAST* id, TypeSpecifierAST** typeSpeci
     target = QualifiedIdentifier();
   }
 
-  m_nameCompiler->run(id, &target);
+  m_nameCompiler.run(id, &target);
   if( typeSpecifier )
-    *typeSpecifier = m_nameCompiler->lastTypeSpecifier();
-}
-
-bool ContextBuilder::smart() const {
-  return editor()->smart();
+    *typeSpecifier = m_nameCompiler.lastTypeSpecifier();
 }
