@@ -45,9 +45,7 @@ enum SignalSlotFlags {
   FunctionIsSlot = 1 << 5
 };
 
-class DeclarationBuilderBase : public KDevelop::AbstractDeclarationBuilder<AST, NameAST, TypeBuilder>
-{
-};
+typedef TypeBuilder DeclarationBuilderBase;
 
 /**
  * A class which iterates the AST to extract definitions of types.
@@ -56,7 +54,6 @@ class KDEVCPPDUCHAIN_EXPORT DeclarationBuilder: public DeclarationBuilderBase
 {
 public:
   DeclarationBuilder(ParseSession* session);
-  DeclarationBuilder(CppEditorIntegrator* editor);
 
   /**
    * Compile either a context-definition chain, or add uses to an existing
@@ -76,7 +73,7 @@ public:
    *
    * \param parent Context that will be used as parent for this context
    */
-//   KDevelop::DUContext* buildSubDeclarations(const HashedString& url, AST *node, KDevelop::DUContext* parent = 0);
+//   KDevelop::DUContext* buildSubDeclarations(const IndexedString& url, AST *node, KDevelop::DUContext* parent = 0);
 
   bool changeWasSignificant() const;
 
@@ -111,7 +108,7 @@ private:
   //Also collects the Qt function signature if required. In that case, true is always returned.
   bool checkParameterDeclarationClause(ParameterDeclarationClauseAST* clause);
   //Du-chain must be locked
-  QualifiedIdentifier resolveNamespaceIdentifier(const QualifiedIdentifier& identifier, const KDevelop::SimpleCursor& position);
+  QualifiedIdentifier resolveNamespaceIdentifier(const QualifiedIdentifier& identifier, const KDevelop::CursorInRevision& position);
 
   KDevelop::ForwardDeclaration* openForwardDeclaration(NameAST* name, AST* range);
   /**
@@ -124,7 +121,7 @@ private:
   template<class T>
   T* openDeclaration(NameAST* name, AST* range, const Identifier& customName = Identifier(), bool collapseRange = false, bool collapseRangeAtEnd = false);
   template<class T>
-  T* openDeclarationReal(NameAST* name, AST* range, const Identifier& customName, bool collapseRangeAtStart, bool collapseRangeAtEnd, const SimpleRange* customRange = 0);
+  T* openDeclarationReal(NameAST* name, AST* range, const Identifier& customName, bool collapseRangeAtStart, bool collapseRangeAtEnd, const RangeInRevision* customRange = 0);
   /// Same as the above, but sets it as the definition too @param forceInstance when this is true, the declaration is forced to be an instance, not a type declaration,
   /// and its assigned identified type will not get the declaration assigned.
   virtual void closeDeclaration(bool forceInstance = false);
@@ -149,6 +146,7 @@ private:
 
   void parseComments(const ListNode<uint> *comments);
 
+  void eventuallyAssignInternalContext();
   void applyStorageSpecifiers();
   void applyFunctionSpecifiers();
   void popSpecifiers();
@@ -174,6 +172,24 @@ private:
   QMultiHash<DUContext*, PropertyResolvePair> m_pendingPropertyDeclarations;
   KDevelop::IndexedDeclaration resolveMethodName(NameAST *node);
   void resolvePendingPropertyDeclarations(const QList<PropertyResolvePair> &pairs);
+  
+  /// Inherited from AbstractDeclarationBuilder:
+
+  inline Declaration* currentDeclaration() const { return m_declarationStack.isEmpty() ? 0 : m_declarationStack.top(); }
+  /// Access the current declaration, casted to type \a DeclarationType. \returns the current declaration if one exists and is an instance of the given \a DeclarationType.
+  template<class DeclarationType>
+  inline DeclarationType* currentDeclaration() const { return m_declarationStack.isEmpty() ? 0 : dynamic_cast<DeclarationType*>(m_declarationStack.top()); }
+
+  /// Access the current comment. \returns the current comment, or an empty string if none exists.
+  inline const QByteArray& comment() const { return m_lastComment; }
+  /// Set the current \a comment. \param comment the new comment.
+  inline void setComment(const QByteArray& comment) { m_lastComment = comment; }
+  /// Clears the current comment.
+  inline void clearComment() { m_lastComment.clear(); }
+
+private:
+  QStack<Declaration*> m_declarationStack;
+  QByteArray m_lastComment;  
 };
 
 #endif // DECLARATIONBUILDER_H
