@@ -50,12 +50,12 @@ int KDevelop::SourceCodeInsertion::firstValidCodeLineBefore(int lineNumber) cons
     int lastComment = -1;
 
     for(int a = 0; a < checkLines; ++a) {
-      if(lines[a].startsWith('$')) {
+      if(lines.at(a).startsWith('$')) {
         chosen = -1;
         lastComment = a;
         continue;
       }
-      QString trimmedLine = lines[a].trimmed();
+      QString trimmedLine = lines.at(a).trimmed();
       if(trimmedLine.startsWith('#')) {
         lastDefine = a;
         chosen = -1;
@@ -138,7 +138,7 @@ void KDevelop::SourceCodeInsertion::setSubScope(KDevelop::QualifiedIdentifier sc
       
       foreach(DUContext* child, context->childContexts()) {
         kDebug() << "checking child" << child->localScopeIdentifier().toString() << "against" << needNamespace.first();
-        if(child->localScopeIdentifier().toString() == needNamespace.first() && child->type() == DUContext::Namespace && (child->range().start < m_insertBefore || !m_insertBefore.isValid())) {
+        if(child->localScopeIdentifier().toString() == needNamespace.first() && child->type() == DUContext::Namespace && (child->rangeInCurrentRevision().start < m_insertBefore || !m_insertBefore.isValid())) {
           kDebug() << "taking";
           context = child;
           foundChild = true;
@@ -177,8 +177,10 @@ void KDevelop::SourceCodeInsertion::setAccess(KDevelop::Declaration::AccessPolic
   m_access = access;
 }
 
-KDevelop::SourceCodeInsertion::SourceCodeInsertion(KDevelop::TopDUContext* topContext) : m_context(topContext), m_access(Declaration::Public), m_topContext(topContext),
-                                                   m_codeRepresentation(KDevelop::createCodeRepresentation(m_topContext->url())){
+KDevelop::SourceCodeInsertion::SourceCodeInsertion(KDevelop::TopDUContext* topContext)
+  : m_context(topContext), m_access(Declaration::Public), m_topContext(topContext),
+    m_codeRepresentation(KDevelop::createCodeRepresentation(m_topContext->url()))
+{
   if(m_topContext->parsingEnvironmentFile() && m_topContext->parsingEnvironmentFile()->isProxyContext()) {
     kWarning() << "source-code manipulation on proxy-context is wrong!!!" << m_topContext->url().toUrl();
   }
@@ -215,7 +217,7 @@ QString KDevelop::SourceCodeInsertion::indentation() const {
     QString textLine = m_codeRepresentation->line(decl->range().start.line);
     
     for(int a = 0; a < textLine.size(); ++a) {
-      if(textLine[a].isSpace())
+      if(textLine.at(a).isSpace())
         ++spaces;
       else
         break;
@@ -262,9 +264,9 @@ SimpleRange SourceCodeInsertion::insertionRange(int line)
   {
     SimpleRange range(line-1, m_codeRepresentation->line(line-1).size(), line-1, m_codeRepresentation->line(line-1).size());
     //If the context finishes on that line, then this will need adjusting
-    if(!m_context->range().textRange().contains(range.textRange()))
+    if(!m_context->rangeInCurrentRevision().textRange().contains(range.textRange()))
     {
-      range.start = m_context->range().end;
+      range.start = m_context->rangeInCurrentRevision().end;
       if(range.start.column > 0)
         range.start.column -= 1;
       range.end = range.start;
@@ -316,7 +318,7 @@ bool KDevelop::SourceCodeInsertion::insertVariableDeclaration(KDevelop::Identifi
 
 SimpleCursor SourceCodeInsertion::end() const
 {
-  SimpleCursor ret = m_context->range().end;
+  SimpleCursor ret = m_context->rangeInCurrentRevision().end;
   if(m_codeRepresentation && m_codeRepresentation->lines() && dynamic_cast<TopDUContext*>(m_context)) {
     ret.line = m_codeRepresentation->lines()-1;
     ret.column = m_codeRepresentation->line(ret.line).size();
@@ -353,7 +355,7 @@ SourceCodeInsertion::InsertionPoint SourceCodeInsertion::findInsertionPoint(KDev
         }
       }
     }
-    kDebug() << ret.line << m_context->scopeIdentifier(true) << m_context->range().textRange() << behindExistingItem << m_context->url().toUrl() << m_context->parentContext();
+    kDebug() << ret.line << m_context->scopeIdentifier(true) << m_context->rangeInCurrentRevision().textRange() << behindExistingItem << m_context->url().toUrl() << m_context->parentContext();
     kDebug() << "is proxy:" << m_context->topContext()->parsingEnvironmentFile()->isProxyContext() << "count of declarations:" << m_context->topContext()->localDeclarations().size();
     
     if(!behindExistingItem) {
@@ -457,9 +459,9 @@ bool Cpp::SourceCodeInsertion::insertForwardDeclaration(KDevelop::Declaration* d
     
     bool needNewLine = true;
     
-    if(!m_scope.isEmpty() || (m_insertBefore.isValid() && m_context->range().end > m_insertBefore)) {
+    if(!m_scope.isEmpty() || (m_insertBefore.isValid() && m_context->rangeInCurrentRevision().end > m_insertBefore)) {
       //To the begin
-      position = m_context->range().start.textCursor();
+      position = m_context->rangeInCurrentRevision().start.textCursor();
       
       if(m_context->type() == DUContext::Namespace) {
           position += KTextEditor::Cursor(0, 1); //Skip over the opening '{' paren
