@@ -31,7 +31,6 @@
 #include "dumpchain.h"
 
 #include <language/duchain/identifier.h>
-#include <language/duchain/dumpchain.h>
 #include <language/duchain/types/abstracttype.h>
 #include <language/duchain/types/indexedtype.h>
 
@@ -48,8 +47,8 @@ class TestExpressionParser : public QObject
 public:
   TestExpressionParser();
 
-  KDevelop::Declaration* findDeclaration(KDevelop::DUContext* context, const KDevelop::Identifier& id, const KDevelop::SimpleCursor& position = KDevelop::SimpleCursor::invalid());
-  KDevelop::Declaration* findDeclaration(KDevelop::DUContext* context, const KDevelop::QualifiedIdentifier& id, const KDevelop::SimpleCursor& position = KDevelop::SimpleCursor::invalid());
+  KDevelop::Declaration* findDeclaration(KDevelop::DUContext* context, const KDevelop::Identifier& id, const KDevelop::CursorInRevision& position = KDevelop::CursorInRevision::invalid());
+  KDevelop::Declaration* findDeclaration(KDevelop::DUContext* context, const KDevelop::QualifiedIdentifier& id, const KDevelop::CursorInRevision& position = KDevelop::CursorInRevision::invalid());
 
 private slots:
   void initTestCase();
@@ -89,7 +88,6 @@ private:
 
   // Parser
   Control control;
-  KDevelop::DumpChain dumper;
   Cpp::DumpChain cppDumper;
 
   KDevelop::AbstractType::Ptr typeVoid;
