@@ -22,7 +22,6 @@
 #include "control.h"
 #include "parsesession.h"
 #include "rpp/pp-scanner.h"
-#include <language/editor/hashedstring.h>
 
 #include <cctype>
 #include <util/kdevvarlengtharray.h>
@@ -964,9 +963,9 @@ KDevelop::ProblemPointer Lexer::createProblem() const
 
   KDevelop::ProblemPointer p(new KDevelop::Problem);
 
-  KDevelop::SimpleCursor position = session->positionAt(cursor.offsetIn(session->contents()), true);
+  KDevelop::CursorInRevision position = session->positionAt(cursor.offsetIn(session->contents()), true);
   p->setSource(KDevelop::ProblemData::Lexer);
-  p->setFinalLocation(KDevelop::DocumentRange(session->url().str(), KTextEditor::Range(position.textCursor(), 1)));
+  p->setFinalLocation(KDevelop::DocumentRange(session->url(), KDevelop::SimpleRange(position.castToSimpleCursor(), 1)));
 
   return p;
 }
