@@ -1080,26 +1080,9 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
             addOutputArgument(func.arguments[2]);
             break;
         case Glob:
-            addOutputArgument(func.arguments[1]);
-            m_variable = func.arguments[1].value;
-            it=func.arguments.constBegin()+2;
-            itEnd=func.arguments.constEnd();
-
-            for(; it!=itEnd; ++it) {
-                if(it->value=="RELATIVE") {
-                    it++;
-                    if(it==itEnd)
-                        return false;
-                    else
-                        m_path = it->value;
-                } else
-                    m_globbingExpressions << it->value;
-            }
-            break;
         case GlobRecurse:
             addOutputArgument(func.arguments[1]);
             m_variable = func.arguments[1].value;
-            m_isFollowingSymlinks = false;
             it=func.arguments.constBegin()+2;
             itEnd=func.arguments.constEnd();
             
@@ -1110,8 +1093,6 @@ bool FileAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                         return false;
                     else
                         m_path = it->value;
-                } else if(it->value=="FOLLOW_SYMLINKS") {
-                    m_isFollowingSymlinks = true;
                 } else
                     m_globbingExpressions << it->value;
             }
@@ -1496,7 +1477,7 @@ bool FindPathAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 FindProgramAst::FindProgramAst()
 {
         m_noDefaultPath = m_noCmakeEnvironmentPath = m_noCmakePath =
-        m_noSystemEnvironmentPath = m_noSystemEnvironmentPath = false;
+        m_noSystemEnvironmentPath = false;
 }
 
 FindProgramAst::~FindProgramAst()
